@@ -39,8 +39,8 @@
 --      Salt Lake City, UT 84127-0511, USA.
 --
 --   $Author: jsedwards $
---   $Date: 2010-01-17 11:08:52 -0700 (Sun, 17 Jan 2010) $
---   $Revision: 4458 $
+--   $Date: 2010-02-28 06:39:35 -0700 (Sun, 28 Feb 2010) $
+--   $Revision: 4599 $
 --
 --   NOTE: Subversion does not support the Log keyword so I have removed the
 --   logs that were here when I was using CVS.  Use the "svn log" command to
@@ -292,7 +292,7 @@ void list_files(Option option)
 	copy_reference(&sorted_assoc_refs[i - 1], &sorted_assoc_refs[0]);
 
 	j = 1;
-	while (j < (i / 2) - 1)
+	while (j * 2 < i)
 	{
 	    k = j * 2;
 
